@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 /*
@@ -24,11 +24,11 @@ extern void log_guess(char *login, char *ciphertext, char *plaintext);
 /*
  * Writes the log file buffer to disk.
  */
-extern void log_flush();
+extern void log_flush(void);
 
 /*
  * Closes the log file.
  */
-extern void log_done();
+extern void log_done(void);
 
 #endif
