@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 /*
@@ -19,6 +19,11 @@
  */
 extern char *rec_name;
 
+/*
+ * Crash recovery file format version number.
+ */
+extern int rec_version;
+
 /*
  * Original command line arguments.
  */
@@ -34,7 +39,7 @@ extern void rec_init(struct db_main *db, void (*save_mode)(FILE *file));
 /*
  * Saves the command line arguments and cracking mode specific information.
  */
-extern void rec_save();
+extern void rec_save(void);
 
 /*
  * Closes the crash recovery file.
