@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 /*
@@ -27,7 +27,7 @@ struct status_main {
 
 extern struct status_main status;
 
-extern int (*status_get_progress)();
+extern int (*status_get_progress)(void);
 
 /*
  * Elapsed time of previous sessions, in seconds.
@@ -35,11 +35,11 @@ extern int (*status_get_progress)();
 extern unsigned int status_restored_time;
 
 /*
- * If start is non-zero, sets start_time to current time minus
- * status_restored_time, and the rest of fields to zero. Always
- * initializes the get_progress() handler (can be NULL).
+ * If start is non-zero, sets start_time to current time and the rest of
+ * fields to zero. Always initializes the get_progress() handler (can be
+ * NULL).
  */
-extern void status_init(int (*get_progress)(), int start);
+extern void status_init(int (*get_progress)(void), int start);
 
 /*
  * Updates the crypts count.
@@ -48,16 +48,12 @@ extern void status_update_crypts(unsigned int count);
 
 /*
  * Returns the elapsed time in seconds.
- *
- * Currently this does not support running for more than 248 days total
- * (assuming CLK_TCK is 100). However, this should survive uptimes of the
- * box we are running on of more than 248 days.
  */
-extern unsigned int status_get_time();
+extern unsigned int status_get_time(void);
 
 /*
  * Prints current status to stdout.
  */
-extern void status_print();
+extern void status_print(void);
 
 #endif
